BuildMode enum

The build mode enum.

Used to determine the current build mode.

Inheritance
Available extensions

Values

debug → const BuildMode

The debug build mode.

const BuildMode('Debug')
profile → const BuildMode

The profile build mode.

const BuildMode('Profile')
release → const BuildMode

The release build mode.

const BuildMode('Release')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
The description of the build mode.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BuildMode>
A constant List of the values in this enum, in order of their declaration.