DeviceUtils class
A utility class for device information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
androidDeviceInfo
→ Future<
AndroidDeviceInfo> -
Returns a Future resolving into
AndroidDeviceInfo.no setter - currentBuildMode → BuildMode
-
Returns the current build mode.
no setter
-
iosDeviceInfo
→ Future<
IosDeviceInfo> -
Returns a Future resolving into
IosDeviceInfo.no setter
Static Methods
-
getDeviceInfo(
) → Future< DeviceInfo> - Returns unified device information for the current platform.