FlavorBanner class
A widget that displays a banner with the flavor name.
The banner is displayed on top of the child and can be long pressed to show a dialog with the device info.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlavorBanner
Constructors
- FlavorBanner({required Widget child, String? message, TextStyle? bannerTextStyle, VoidCallback? onLongPress, BannerLocation? location, Size? size, String? deviceInfoDialogTitle, TextStyle? deviceInfoDialogTitleStyle, Key? key})
-
Creates a FlavorBanner widget.
const
Properties
-
The text style of the banner.
final
- child → Widget
-
The widget that will be rendered on top of the banner.
final
- deviceInfoDialogTitle → String?
-
The title of the device info dialog.
final
- deviceInfoDialogTitleStyle → TextStyle?
-
The text style of the device info dialog title.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- location → BannerLocation?
-
The location of the banner.
final
- message → String?
-
The message to display in the banner.
final
-
The GlobalKey for when the FlavorBanner in not in a context with
that includes a Navigator.
final
- onLongPress → VoidCallback?
-
The callback that will be called when the banner is long pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size?
-
The size of the banner.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited